Angle

Enum Angle 

pub enum Angle {
    Degrees(f64),
    Radians(f64),
}
An angle.

Angles or phases are more commonly written in radians in physics, but may be more convenient to write in degrees. Furthermore, explicitly denoting the units for angles prevents confusion or mistakes.

Variants



Degrees(f64)



Radians(f64)